@@ -13,6 +13,7 @@
 
 # https://github.com/elesiuta/backupy
 
+import json
 import os
 import re
 import typing
@@ -80,10 +81,15 @@ class FileScanner:
 
     def saveDatabase(self, db_name: str = "database.json") -> None:
         """Write database to config_dir on self and other if enabled"""
+        self_entry = os.path.join(self.config_dir, "database")
+        self_crc = self.calcDatabaseCrc(self.dict_current)
+        assert self_entry not in self.dict_current
+        self.dict_current[self_entry] = {"size": 0, "mtime": 0, "crc": self_crc, "dir": False}
         writeJson(os.path.join(self.dir, self.config_dir, db_name), self.dict_current, sort_keys=True)
         if self.write_database_x2:
             other_db_path = os.path.join(self.other_dir, self.config_dir, "database-%s%s" % (self.unique_id, db_name[8:]))
             writeJson(other_db_path, self.dict_current, sort_keys=True)
+        _ = self.dict_current.pop(self_entry)
 
     def loadDatabase(self, use_cold_storage: bool = False) -> None:
         """Load database from config_dir"""
@@ -93,17 +99,35 @@ class FileScanner:
             self.dict_prev = local_dict.copy()
             self.set_unmodified = set(self.dict_current.keys())
         else:
-            self.dict_prev = readJson(os.path.join(self.dir, self.config_dir, "database.json"))
+            db_path = os.path.join(self.dir, self.config_dir, "database.json")
+            self.dict_prev = readJson(db_path)
+            self.verifyDatabaseCrc(self.dict_prev, db_path)
 
     def getDatabaseX2(self, fallback: bool = True) -> dict:
         """Get the 'last seen' database of this directory from the perspective of the other directory"""
         other_db_path = os.path.join(self.other_dir, self.config_dir, "database-%s.json" % self.unique_id)
         database_x2 = readJson(other_db_path)
+        self.verifyDatabaseCrc(database_x2, other_db_path)
         if database_x2 or not fallback:
             return database_x2
         else:
             return self.dict_prev
 
+    def calcDatabaseCrc(self, database: dict) -> str:
+        return "%X" % (zlib.crc32(json.dumps(database, sort_keys=True).encode()) & 0xFFFFFFFF)
+
+    def verifyDatabaseCrc(self, database: dict, abs_db_path: str) -> None:
+        """Verify the data in the database matches the CRC and pops the entry, otherwise raises exception"""
+        self_entry = os.path.join(self.config_dir, "database")
+        if self_entry in database:
+            crc_record = database.pop(self_entry)["crc"]
+            crc_calc = self.calcDatabaseCrc(database)
+            if crc_record != crc_calc:
+                raise Exception("Warning: CRC of database contents (%s) does not match recorded CRC (%s), database may be corrupted.\n"
+                                "Inspection of database and files is recommended if this was not triggered by manually editing the database.\n"
+                                "Hint: try -c crc --dry-run after creating a backup copy of the current database then editing it to continue.\n"
+                                "To continue, remove entry %s from %s." % (crc_calc, crc_record, self_entry, abs_db_path))
+
     def verifyCrcOnCopy(self, source_root: str, dest_root: str, source_file: str, dest_file: str, other_scanner: 'FileScanner') -> None:
         if self.dir == source_root and other_scanner.dir == dest_root:
             if other_scanner.getCrc(dest_file, recalc=True) != self.getCrc(source_file):
@@ -232,7 +256,7 @@ class FileScanner:
                     full_path = os.path.join(dir_path, subdir)
                     try:
                         if len(FileOps.listdir(full_path)) == 0 or FileOps.islink(full_path):
-                            # track empty directories with a dummy entry, non-empty directories should not have entries, they are handled automatically by having files inside them
+                            # track empty directories and symbolic links to directories with a dummy entry, non-empty directories should not have entries, they are handled automatically by having files inside them
                             relative_path = os.path.relpath(full_path, self.dir)
                             if self.force_posix_path_sep:
                                 relative_path = relative_path.replace(os.path.sep, "/")
